@@ -192,6 +192,11 @@ class Gene_Ontology_enrichment:
     # fixme-done: check it.
     def p_adjust(self, method='BH'):
         count_terms = len(self.enrich_result.terms_p_value.keys())
+
+        if method not in {'BH', 'Bonferroui'}:
+            raise TypeError('Method must be "BH" or "Bonferroui"')
+
+
         if method == 'BH':
 
             sorted_terms = sorted(self.enrich_result.terms_p_value, key=lambda x: self.enrich_result.terms_p_value[x])
@@ -279,7 +284,7 @@ class Gene_Ontology_enrichment:
             print(f'{trait_id:<10}\t{self.id_to_trait[trait_id].trait_name:<50}\t'
                   f'{self.enrich_result.terms_p_value[trait_id]:<.2e}\t'
                   f'{self.enrich_result.terms_p_adjust[trait_id]:<.2e}\t'
-                  f'{self.enrich_result.terms_q_value[trait_id]}:<.2e')
+                  f'{self.enrich_result.terms_q_value[trait_id]:<.2e}')
 
         if save_result:
             if not save_path:
